MailgunClient constructor
initialise a MailgunClient with the default host
domain is the domain of the Mailgun account, and
apiKey is the API key of the Mailgun account
The parameters are passed to all the different clients
Implementation
factory MailgunClient(String domain, String apiKey) =>
MailgunClient._(domain, apiKey, MGDefaults.defaultHost);